@@ -273,7 +273,7 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
 
     # create a column which specifies whether this class was the choice
     temp['choice'] = temp[[choice_col_name,choice_col_name+'_y']].apply(lambda x: 1 if x[0] == x[1] else 0,axis=1)
-    #temp.drop(choice_col_name,axis=1,inplace=True)
+    temp.drop(choice_col_name+'_y',axis=1,inplace=True)
 
     # get the order of the class
     order = sorted(list(temp[choice_col_name].unique()))
@@ -286,7 +286,8 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
 
     # get the total in 2 fields
     totals = temp.groupby(by = [category_col_name,comparison_col_name]).sum().reset_index()
-
+    totals.drop(choice_col_name,axis=1,inplace=True)
+    
     # join the totals onto the groups
     grp = pd.merge(left = grp,right = totals, on=[category_col_name,comparison_col_name],suffixes=('_level','_levelgroup'))
 
@@ -294,7 +295,7 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
     grp['pct in group'] = grp[['Count_level','Count_levelgroup']].apply(lambda x: x[0]*100/x[1],axis=1)
 
     # join the group table to get differences between category_col_name
-    grp_cross_ethnicity = pd.merge(left=grp,right=grp,on=[category_col_name,choice_col_name+'_level'])
+    grp_cross_ethnicity = pd.merge(left=grp,right=grp,on=[category_col_name,choice_col_name])
 
 
     grp_cross_ethnicity = grp_cross_ethnicity[(grp_cross_ethnicity[comparison_col_name+'_x'] == 'C') & (grp_cross_ethnicity[comparison_col_name+'_y'] == 'S')]
@@ -309,7 +310,7 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
     df = pd.pivot_table(data=grp_cross_ethnicity,
                         index=category_col_name,
                         values='ScaledProp',
-                        columns=choice_col_name+'_level')
+                        columns=choice_col_name)
     sns.heatmap(df,annot=False, cmap="RdYlGn",annot_kws={"size": 18},ax=ax,vmin=20, vmax=80)
 
     ax.set_xticklabels(ax.get_xmajorticklabels(), fontsize = 20,rotation=45)
@@ -329,7 +330,7 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
 
     for ix,xlab in enumerate(xlabs):
         for iy,ylab in enumerate(ylabs):
-            temp['value'] = temp[choice_col_name+'_y'].apply(lambda x: 1 if str(x) == xlab else 0)
+            temp['value'] = temp[choice_col_name].apply(lambda x: 1 if str(x) == xlab else 0)
             cohort1 = temp[(temp[comparison_col_name] == comparison_order[0]) & (temp[category_col_name] == ylab) & (temp['choice'] == 1)]
 
             cohort2 = temp[(temp[comparison_col_name] == comparison_order[1]) & (temp[category_col_name] == ylab) & (temp['choice'] == 1)]
